Learn R Programming

RVPedigree (version 0.0.3)

Estim.H0.VCC: Estimate the model parameters under the null model

Description

This function estimates the model parameters under the null model when there is no region genotypes effect, for the VCC methods

Usage

Estim.H0.VCC(y, X, S, U)

Arguments

y
Vector of phenotype values
X
A matrix of covariates, including intercept.
S
Matrix obtained from spectral decomposition of the relationship matrix: $\Phi = U S U^T$.
U
Matrix obtained from spectral decomposition of the relationship matrix: $\Phi = U S U^T$.

Value

a list of:
  • h.hat: estimate of the (narrow sense) heritability
  • gam.hat: a vector of estimates of fixed effects of the covariates (if there are any).
  • residuals: residuals from adjusting the null model with only covariates in the model.