Learn R Programming

RVPedigree (version 0.0.3)

pvalue.VCC1: Compute score and p-value for the VC-C1 method

Description

Compute score and p-value for the VC-C1 method

Usage

pvalue.VCC1(Prep, W, G)

Arguments

Prep
a list of results obtained from the function Preparation.VCC
G
genotype matrix

Value

a list with the score and p-value of the association test in the given region. The list contains the elements score and p.value.

See Also

pvalue.VCC2, pvalue.VCC3