Learn R Programming

RVPedigree (version 0.0.3)

pvalue.VCC2: Compute the p-value for the VC-C2 method

Description

Compute the p-value for the VC-C2 method

Usage

pvalue.VCC2(P, G, W, Nperm, n, pedigree, haplotypes, generation.id, Ncores = 1)

Arguments

P
a matrix which can be obtained as output of the function Preparation.VCC.
G
the genotype matrix
Nperm
(integer) The number of permutations to be done to calculate the empirical p-value if the VCC2 or VCC3 method is used. For other methods this parameter is ignored (default: 100).
n
Integer, the number of samples
pedigree
a pedigree as output by read.pedigree. This is a data frame consisting of four columns (family ID, individual ID, father ID and mother ID) as use in the traditional linkage format and e.g. Plink files.
haplotypes
a matrix of the haplotypes of the individuals
generation.id
a vector of length(sample size) which indicates if the subject is founder (generation.id=0), a child from first generation (generation.id=1), a child from second generation (generation.id=2), etc. This vector can be calculated by the kinship2::kindepth() function.
Ncores
(integer) Number of processor (CPU) cores to be used in parallel when doing the permutations to determine the p-value (default: 1).

Value

a list with the score and p-value for the VC-C2 association test on the given region. The list contains the elements score and p.value. This is a permutation-based p-value.

See Also

pvalue.VCC1, pvalue.VCC3