pvalue.VCC3(P, G, W, Nperm, n, pedigree, haplotypes, generation.id, Ncores = 1)Preparation.VCC.read.pedigree. This is a data frame consisting of
four columns (family ID, individual ID, father ID and mother ID)
as use in the traditional linkage format and e.g. Plink files.generation.id=0),
a child from first generation (generation.id=1), a
child from second generation (generation.id=2), etc.
This vector can be calculated by the
kinship2::kindepth() function.score: The score test
p.value.VCC2: The p-value as output by the VC-C2
method (pvalue.VCC2).
p.value.VCC3: This is the exact p-vlaue for small
level size. The approach to obtain this second p-value
approximates the distribution of the test statistic under the
null model by a non-central chi-square using matching moments
of the first, the second and the fourth moments. The
estimation of the three moments are approximated empirically
using the permutations that were used to calculate the VC-C2
p-value.
pvalue.VCC1, pvalue.VCC2