Learn R Programming

RVPedigree (version 0.0.3)

read.haplo: Read haplotype data, selected by region of interest, from PLINK formatted files or ShapeIt output files

Description

Read haplotype data, selected by region of interest, from PLINK formatted files or ShapeIt output files

Usage

read.haplo(type = "bed", filename, map, chr = 0, startpos = 0, endpos = 0)

Arguments

type
character, 'ped', 'bed' (default) or 'shapeit-haps' format of input file containing haplotype data
filename
character, path to input file containing haplotype data
map
object, data.frame contains 3 columns: rsID, chromosome, position in bp as output by e.g. readMapFile.
chr
character, chromosome number (basically from 1 to 22 as used by Plink), on which the region of interest is located
startpos
numeric, start position (in bp, base pairs) of the region of interest (default: 0)
endpos
numeric, end position (in bp, base pairs) of the region of interest (default: 0)

Value

matrix object containing the haplotypes selected by the region of interest

See Also

read.haplo.pedfile, read.haplo.bedfile, read.haplo.shapeit_haps, readMapFile