Learn R Programming

RVPedigree (version 0.0.3)

read.haplo.pedfile: Read haplotype data, selected by region of interest, from PED files (regular PLINK untransposed text files)

Description

Read haplotype data, selected by region of interest, from PED files (regular PLINK untransposed text files)

Usage

read.haplo.pedfile(filename = "NULL", map, chr = "NULL", startpos = "NULL", endpos = "NULL")

Arguments

filename
character, path to PED file containing haplotype data. Attention! filename should contain path to .ped with full file name. For example ../mydata/inputplink.ped
map
object, data.frame contains 3 columns: rsID, chromosome, position in bp as output by e.g. readMapFile.
chr
character, chromosome number (basically from 1 to 22 as used by Plink), on which the region of interest is located
startpos
numeric, start position (in bp, base pairs) of the region of interest (default: 0)
endpos
numeric, end position (in bp, base pairs) of the region of interest (default: 0)

Value

matrix object containing the haplotypes selected by the region of interest

See Also

read.haplo, read.haplo.bedfile, read.haplo.shapeit_haps, readMapFile