Learn R Programming

RVPedigree (version 0.0.3)

read.pedigree: Read pedigree structure from a Plink file

Description

Extract the pedigree data from a Plink file (in .ped or .bed format). For example, in the case of a .ped file this simply extracts the first four columns from the file.

Usage

read.pedigree(type, filename)

Arguments

type
character, 'ped', 'bed': format of the input file (see the filename parameter) containing the pedigree data (and usually the genomic data as well).
filename
character, path to the input file containing the pedigree data.

Value

a data frame containing the columns with pedigree data taken from the input file (i.e. family ID, individual ID, father ID, mother ID)